@@ -13,7 +13,7 @@ from polytope_feature.shapes import Box, Select
 
 class TestHealpixNestedGrid:
     def setup_method(self, method):
-        nexus_url = "https://get.ecmwf.int/test-data/polytope/test-data/healpix_nested.grib"
+        nexus_url = "https://sites.ecmwf.int/repository/polytope/test-data/healpix_nested.grib"
         download_test_data(nexus_url, "healpix_nested.grib")
 
         ds = data.from_source("file", "./tests/data/healpix_nested.grib")[3]
@@ -113,7 +113,6 @@ class TestHealpixNestedGrid:
         self.slicer = HullSlicer()
         self.API = Polytope(
             datacube=self.latlon_array,
-            engine=self.slicer,
             options=self.options,
         )
 
