@@ -2,7 +2,6 @@ import numpy as np
 import pandas as pd
 import xarray as xr
 
-from polytope_feature.engine.hullslicer import HullSlicer
 from polytope_feature.polytope import Polytope, Request
 from polytope_feature.shapes import Select
 
@@ -27,10 +26,8 @@ class TestMergeTransformation:
             ],
             "compressed_axes_config": ["date", "time"],
         }
-        self.slicer = HullSlicer()
         self.API = Polytope(
             datacube=self.array,
-            engine=self.slicer,
             options=self.options,
         )
 
